@@ -16,8 +16,8 @@ def json_model_dict(raw_object, use_float_seconds=True):
 
     return result
 
-def json_model_collection(raw_collection, use_float_seconds=True):
+def json_model_collection(raw_collection, use_float_seconds=True, **kwargs):
     result = []
     for model in raw_collection:
-        result.append(json_model_dict(model.dict(), use_float_seconds=use_float_seconds))
+        result.append(json_model_dict(model.dict(**kwargs), use_float_seconds=use_float_seconds))
     return result
