@@ -58,6 +58,7 @@ class ModelViewBase(APIView):
 
 class ModelCollectionView(ModelViewBase):
     MODEL_COLLECTION_CLASS = None
+    ORDERABLE_FIELDS = []
     DEFAULT_PAGE_SIZE = getattr(settings, DEFAULT_PAGINATION_SIZE, eggplant_defaults.EGGPLANT_DEFAULT_PAGINATION_SIZE)
 
     #-------------------------------------------------------------------------------------------------------------------
@@ -88,7 +89,24 @@ class ModelCollectionView(ModelViewBase):
         # Get query set
         query_set = self.queryset(*args, **kwargs)
 
-        # TODO: Add Order and Filter
+        # Order
+        raw_order = self.request.GET.get('order', None)
+        if raw_order:
+            orders = []
+            raw_orders = raw_order.split(',')
+            for raw_order in raw_orders:
+                if raw_order.startswith('-'):
+                    order = raw_order[1:]
+                    direction = -1
+                else:
+                    order = raw_order
+                    direction = 1
+                if order in self.ORDERABLE_FIELDS:
+                    orders += [(direction, order)]
+            if len(orders):
+                query_set = self.order(query_set, orders, *args, **kwargs)
+
+        # TODO: filter
 
         meta_info = {}
         # Pagination
@@ -210,6 +228,19 @@ class ModelCollectionView(ModelViewBase):
             raise ImproperlyConfigured, 'Forget to set MODEL_CLASS for this ModelCollectionView'
         return ModelClass.objects.all()
 
+    def order(self, query_set, orders, *args, **kwargs):
+        result_order_list = []
+        for direction, raw_field in orders:
+            order = self.field_for_order(raw_field, direction)
+            if isinstance(order, (list, tuple)):
+                result_order_list += order
+            else:
+                result_order_list += [order]
+        return query_set.order_by(*result_order_list)
+
+    def field_for_order(self, order, direction, *args, **kwargs):
+        return order if direction==1 else '-'+order
+
     def model_presenter(self, *args, **kwargs):
         return lambda x: getattr(x, 'json_dict')(summary=True)
 
